@@ -1,7 +1,10 @@
+# SPDX-FileCopyrightText: Copyright (c) 2020 Bryan Siepert for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
 import time
 import board
 import busio
-from adafruit_lsm6ds import LSM6DSOX
+from adafruit_lsm6ds.lsm6dsox import LSM6DSOX
 
 i2c = busio.I2C(board.SCL, board.SDA)
 
